==> weather_forecast-1.0.0.tar.gz: weather_forecast/src/Plugin/Block/WeatherForecastBlock.php <==
<?php

namespace Drupal\weather_forecast\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use GuzzleHttp\ClientInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'WeatherForecast' block.
 *
 * @Block(
 *   id = "weather_forecast_block",
 *   admin_label = @Translation("Weather Forecast Block"),
 * )
 */
class WeatherForecastBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * HTTP Client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * A logger instance.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * Constructs a new WeatherForecastBlock.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \GuzzleHttp\ClientInterface $http_client
   *   HTTP client for fetching weather data.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ClientInterface $http_client, LoggerInterface $logger) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->httpClient = $http_client;
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('http_client'),
      $container->get('logger.factory')->get('action'),

    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $api_key = '475c6f6daeba27ab243cfcf40c20a8c7';

    $city = $this->configuration['city'] ?? 'London';

    $url = "https://api.openweathermap.org/data/2.5/weather?q={$city}&appid={$api_key}&units=metric";

    try {
      $response = $this->httpClient->request('GET', $url);
      $data = json_decode($response->getBody(), TRUE);

      if (!empty($data)) {
        return [
          '#theme' => 'weather_forecast',
          '#city' => $data['name'],
          '#temp' => $data['main']['temp'],
          '#description' => $data['weather'][0]['description'],
          '#humidity' => $data['main']['humidity'],
          '#wind_speed' => $data['wind']['speed'],
          '#cache' => [
            'max-age' => 3600,
          ],
        ];
      }
      else {
        return [
          '#markup' => $this->t('Unable to fetch weather data.'),
        ];
      }
    }
    catch (\Exception $e) {
      $this->logger->error($e->getMessage());
      return [
        '#markup' => $this->t('Unable to fetch weather data.'),
      ];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form['city'] = [
      '#type' => 'textfield',
      '#title' => $this->t('City'),
      '#default_value' => $this->configuration['city'] ?? 'London',
      '#description' => $this->t('Enter the city for which you want to display the weather.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['city'] = $form_state->getValue('city');
  }

}

==> weather_forecast-1.0.2.tar.gz: weather_forecast/src/Plugin/Block/WeatherForecastBlock.php <==
<?php

namespace Drupal\weather_forecast\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use GuzzleHttp\ClientInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'WeatherForecast' block.
 *
 * @Block(
 *   id = "weather_forecast_block",
 *   admin_label = @Translation("Weather Forecast Block"),
 * )
 */
class WeatherForecastBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * HTTP Client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * A logger instance.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * Constructs a new WeatherForecastBlock.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \GuzzleHttp\ClientInterface $http_client
   *   HTTP client for fetching weather data.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ClientInterface $http_client, LoggerInterface $logger) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->httpClient = $http_client;
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('http_client'),
      $container->get('logger.factory')->get('action'),

    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    // $api_key = '475c6f6daeba27ab243cfcf40c20a8c7';
    $api_key = \Drupal::config('weather_forecast.weather_settings')->get('api_key');

    $city = $this->configuration['city'] ?? 'London';

    $url = "https://api.openweathermap.org/data/2.5/weather?q={$city}&appid={$api_key}&units=metric";

    try {
      $response = $this->httpClient->request('GET', $url);
      $data = json_decode($response->getBody(), TRUE);

      if (!empty($data)) {
        return [
          '#theme' => 'weather_forecast',
          '#city' => $data['name'],
          '#temp' => $data['main']['temp'],
          '#description' => $data['weather'][0]['description'],
          '#humidity' => $data['main']['humidity'],
          '#wind_speed' => $data['wind']['speed'],
          '#cache' => [
            'max-age' => 3600,
          ],
        ];
      }
      else {
        return [
          '#markup' => $this->t('Unable to fetch weather data.'),
        ];
      }
    }
    catch (\Exception $e) {
      $this->logger->error($e->getMessage());
      return [
        '#markup' => $this->t('Unable to fetch weather data.'),
      ];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form['city'] = [
      '#type' => 'textfield',
      '#title' => $this->t('City'),
      '#default_value' => $this->configuration['city'] ?? 'London',
      '#description' => $this->t('Enter the city for which you want to display the weather.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['city'] = $form_state->getValue('city');
  }

}
